# Delivery Schema

##

Type: object

Exact address

##

Type: string

##

Type: string

##

Type: string

##

Type: object

Exact address

##

Type: string

##

Type: string

##

Type: string

##

Delivery info depending on the delivery type

## One of

Type: object Property name must match regular expression: `Option 1`

##

Type: number
Type: object

The delivery is a gift, no prices displayed

Property name must match regular expression: `Option 2`

##

Type: boolean